pub struct ProbeOptions {
    pub chip: Option<String>,
    pub chip_description_path: Option<PathBuf>,
    pub protocol: Option<WireProtocol>,
    pub probe_selector: Option<DebugProbeSelector>,
    pub speed: Option<u32>,
    pub connect_under_reset: bool,
    pub dry_run: bool,
    pub allow_erase_all: bool,
}
Common options and logic when interfacing with a Probe.

Fields

chip: Option<String>chip_description_path: Option<PathBuf>protocol: Option<WireProtocol>

Protocol used to connect to chip. Possible options: [swd, jtag]

probe_selector: Option<DebugProbeSelector>

Use this flag to select a specific probe in the list.

Use ‘–probe VID:PID’ or ‘–probe VID:PID:Serial’ if you have more than one probe with the same VID:PID.“,

speed: Option<u32>connect_under_reset: booldry_run: boolallow_erase_all: bool

Implementations

Add targets contained in file given by –chip-description-path to probe-rs registery.

Note: should be called before FlashOptions::early_exit and any other functions in ProbeOptions.

Resolves a resultant target selector from passed ProbeOptions.

Attaches to specified probe and configures it.

Attaches to target device session. Attaches under reset if specified by ProbeOptions::connect_under_reset.

Convenience method that attaches to the specified probe, target, and target session.

Builds a new flash loader for the given target and ELF. This will check the ELF for validity and check what pages have to be flashed etc.