[−][src]Function probe_rs_cli_util::logging::capture_error
pub fn capture_error<E: ?Sized>(metadata: &Metadata, error: &E) where
E: Error,
Captures an std::error::Error with sentry and sends all previously captured logs.
pub fn capture_error<E: ?Sized>(metadata: &Metadata, error: &E) where
E: Error,
Captures an std::error::Error with sentry and sends all previously captured logs.