[−][src]Function probe_rs_cli_util::logging::capture_panic
pub fn capture_panic(metadata: &Metadata, info: &PanicInfo<'_>)
Captures a panic with sentry and sends all previously captured logs.
pub fn capture_panic(metadata: &Metadata, info: &PanicInfo<'_>)
Captures a panic with sentry and sends all previously captured logs.