Function probe_rs_cli_util::logging::clear_progress_bar
source · pub fn clear_progress_bar()Expand description
Disables the currently displayed progress bar of the CLI.
pub fn clear_progress_bar()Disables the currently displayed progress bar of the CLI.