[−][src]Function probe_rs_cli_util::logging::println
pub fn println(message: impl AsRef<str>)
Writes a message to stdout with a newline at the end. This function respects the progress bars of the CLI that might be displayed and displays the message above it if any are.