ChannelMode

Enum ChannelMode 

#[repr(u32)]
pub enum ChannelMode { NoBlockSkip = 0, NoBlockTrim = 1, BlockIfFull = 2, }
Specifies what to do when a channel doesn’t have enough buffer space for a complete write on the target side.

Variants



NoBlockSkip = 0

Skip writing the data completely if it doesn’t fit in its entirety.



NoBlockTrim = 1

Write as much as possible of the data and ignore the rest.



BlockIfFull = 2

Block (spin) if the buffer is full. Note that if the application writes within a critical section, using this mode can cause the application to freeze if the buffer becomes full and is not read by the host.