pub struct RttActiveChannel {
    pub up_channel: Option<UpChannel>,
    pub down_channel: Option<DownChannel>,
    pub channel_name: String,
    pub data_format: DataFormat,
    /* private fields */
}
This is the primary interface through which RTT channel data is read and written. Every actual RTT channel has a configuration and buffer that is used for this purpose.

Fields

up_channel: Option<UpChannel>down_channel: Option<DownChannel>channel_name: Stringdata_format: DataFormat

Implementations

source

impl RttActiveChannel

A fully configured RttActiveChannel. The configuration will always try to ‘default’ based on information read from the RTT control block in the binary. Where insufficient information is available, it will use the supplied configuration, with final hardcoded defaults where no other information was available.

source

pub fn new(
up_channel: Option<UpChannel>,
down_channel: Option<DownChannel>,
channel_config: Option<RttChannelConfig>,
timestamp_offset: UtcOffset
) -> Self

source

pub fn number(&self) -> Option<usize>

Returns the number of the UpChannel.

source

pub fn poll_rtt(&mut self, core: &mut Core<'_>) -> Option<usize>

Polls the RTT target for new data on the channel represented by self. Processes all the new data into the channel internal buffer and returns the number of bytes that was read.

source

pub fn get_rtt_data(
&mut self,
core: &mut Core<'_>,
defmt_state: Option<&(Table, Option<Locations>)>
) -> Result<Option<(String, String)>, Error>

Retrieves available data from the channel and if available, returns Some(channel_number:String, formatted_data:String). If no data is available, or we encounter a recoverable error, it returns None value fore formatted_data. Non-recoverable errors are propagated to the caller.

source

pub fn _push_rtt(&mut self, core: &mut Core<'_>)