pub struct RttActiveTarget {
    pub active_channels: Vec<RttActiveChannel>,
    pub defmt_state: Option<(Table, Option<Locations>)>,
}
Once an active connection with the Target RTT control block has been established, we configure each of the active channels, and hold essential state information for successfull communication.

Fields

active_channels: Vec<RttActiveChannel>defmt_state: Option<(Table, Option<Locations>)>

Implementations

source

impl RttActiveTarget

source

pub fn new(
rtt: Rtt,
elf_file: &Path,
rtt_config: &RttConfig,
timestamp_offset: UtcOffset
) -> Result<Self>

RttActiveTarget collects references to all the RttActiveChannels, for latter polling/pushing of data.

source

pub fn get_rtt_symbol<T: Read + Seek>(file: &mut T) -> Option<u64>

source

pub fn poll_rtt(&mut self, core: &mut Core<'_>) -> HashMap<String, String>

👎Deprecated since 0.14.0: This function is deprecated and will be removed in a future version. Please use poll_rtt_fallible instead.

Polls the RTT target on all channels and returns available data. Errors on any channel will be ignored and the data (even if incomplete) from the other channels will be returned.

source

pub fn poll_rtt_fallible(
&mut self,
core: &mut Core<'_>
) -> Result<HashMap<String, String>, Error>

Polls the RTT target on all channels and returns available data. An error on any channel will return an error instead of incomplete data.