Struct probe_rs_cli_util::Artifact[][src]

pub struct Artifact { /* fields omitted */ }
Represents compiled code that the compiler emitted during compilation.

Implementations

Get the path of this output from the compiler.

If true, then the artifact was unchanged during compilation.