Struct probe_rs_cli_util::common_options::CargoOptions[][src]

pub struct CargoOptions {
    pub bin: Option<String>,
    pub example: Option<String>,
    pub package: Option<String>,
    pub release: bool,
    pub target: Option<String>,
    pub manifest_path: Option<PathBuf>,
    pub no_default_features: bool,
    pub all_features: bool,
    pub features: Vec<String>,
    pub trailing_opts: Vec<String>,
}
Common options used when building artifacts with cargo.

Fields

bin: Option<String>example: Option<String>package: Option<String>release: booltarget: Option<String>manifest_path: Option<PathBuf>no_default_features: boolall_features: boolfeatures: Vec<String>trailing_opts: Vec<String>

Escape hatch: all args passed after a sentinel -- end up here, unprocessed. Used to pass arguments to cargo not declared in CargoOptions.

Implementations

Generates a suitable help string to append to your program’s –help. Example usage:

use probe_rs_cli_util::common_options::{FlashOptions, CargoOptions};
use probe_rs_cli_util::structopt::StructOpt;

let matches = FlashOptions::clap()
    .bin_name("cargo flash")
    .after_help(CargoOptions::help_message("cargo flash").as_str())
    .get_matches_from(std::env::args());
let opts = FlashOptions::from_clap(&matches);

Generates list of arguments to cargo from a CargoOptions. For example, if CargoOptions::release is set, resultant list will contain a "--release".