Struct probe_rs_cli_util::common_options::ProbeOptions
source · [−]pub struct ProbeOptions {
pub chip: Option<String>,
pub chip_description_path: Option<PathBuf>,
pub protocol: Option<WireProtocol>,
pub probe_selector: Option<DebugProbeSelector>,
pub speed: Option<u32>,
pub connect_under_reset: bool,
pub dry_run: bool,
pub allow_erase_all: bool,
}Expand description
Common options and logic when interfacing with a Probe.
Fields
chip: Option<String>chip_description_path: Option<PathBuf>protocol: Option<WireProtocol>Protocol used to connect to chip. Possible options: [swd, jtag]
probe_selector: Option<DebugProbeSelector>Use this flag to select a specific probe in the list.
Use ‘–probe VID:PID’ or ‘–probe VID:PID:Serial’ if you have more than one probe with the same VID:PID.“,
speed: Option<u32>connect_under_reset: booldry_run: boolallow_erase_all: boolImplementations
sourceimpl ProbeOptions
impl ProbeOptions
sourcepub fn maybe_load_chip_desc(&self) -> Result<(), OperationError>
pub fn maybe_load_chip_desc(&self) -> Result<(), OperationError>
Add targets contained in file given by –chip-description-path to probe-rs registery.
Note: should be called before FlashOptions::early_exit and any other functions in ProbeOptions.
sourcepub fn get_target_selector(&self) -> Result<TargetSelector, OperationError>
pub fn get_target_selector(&self) -> Result<TargetSelector, OperationError>
Resolves a resultant target selector from passed ProbeOptions.
sourcepub fn attach_probe(&self) -> Result<Probe, OperationError>
pub fn attach_probe(&self) -> Result<Probe, OperationError>
Attaches to specified probe and configures it.
sourcepub fn attach_session(
&self,
probe: Probe,
target: TargetSelector
) -> Result<Session, OperationError>
pub fn attach_session(
&self,
probe: Probe,
target: TargetSelector
) -> Result<Session, OperationError>
Attaches to target device session. Attaches under reset if specified by ProbeOptions::connect_under_reset.
sourcepub fn simple_attach(&self) -> Result<Session, OperationError>
pub fn simple_attach(&self) -> Result<Session, OperationError>
Convenience method that attaches to the specified probe, target, and target session.
sourcepub fn build_flashloader(
&self,
session: &mut Session,
elf_path: &Path
) -> Result<FlashLoader, OperationError>
pub fn build_flashloader(
&self,
session: &mut Session,
elf_path: &Path
) -> Result<FlashLoader, OperationError>
Builds a new flash loader for the given target and ELF. This will check the ELF for validity and check what pages have to be flashed etc.