Struct probe_rs_cli_util::common_options::ProbeOptions [−][src]
pub struct ProbeOptions {
pub chip: Option<String>,
pub chip_description_path: Option<PathBuf>,
pub protocol: Option<WireProtocol>,
pub probe_selector: Option<DebugProbeSelector>,
pub connect_under_reset: bool,
pub speed: Option<u32>,
pub dry_run: bool,
}Expand description
Common options and logic when interfacing with a Probe.
Fields
chip: Option<String>chip_description_path: Option<PathBuf>protocol: Option<WireProtocol>probe_selector: Option<DebugProbeSelector>connect_under_reset: boolspeed: Option<u32>dry_run: boolImplementations
Add targets contained in file given by –chip-description-path to probe-rs registery.
Note: should be called before FlashOptions::early_exit and any other functions in ProbeOptions.
Resolves a resultant target selector from passed ProbeOptions.
Attaches to specified probe and configures it.
pub fn attach_session(
&self,
probe: Probe,
target: TargetSelector
) -> Result<Session, OperationError>
pub fn attach_session(
&self,
probe: Probe,
target: TargetSelector
) -> Result<Session, OperationError>
Attaches to target device session. Attaches under reset if specified by ProbeOptions::connect_under_reset.
Convenience method that attaches to the specified probe, target, and target session.
pub fn build_flashloader(
&self,
session: &mut Session,
elf_path: &Path
) -> Result<FlashLoader, OperationError>
pub fn build_flashloader(
&self,
session: &mut Session,
elf_path: &Path
) -> Result<FlashLoader, OperationError>
Builds a new flash loader for the given target and ELF. This will check the ELF for validity and check what pages have to be flashed etc.