Module probe_rs_cli_util::logging [−][src]
Structs
| Metadata |
Functions
| ask_to_log_crash | Displays the text to ask if the crash should be reported. |
| clear_progress_bar | Disables the currently displayed progress bar of the CLI. |
| eprintln | Writes an error to stderr. This function respects the progress bars of the CLI that might be displayed and displays the message above it if any are. |
| init | Initialize the logger. |
| println | Writes a message to stdout with a newline at the end. This function respects the progress bars of the CLI that might be displayed and displays the message above it if any are. |
| set_progress_bar | Sets the currently displayed progress bar of the CLI. |