[−][src]Module probe_rs_cli_util::logging
Structs
| Metadata |
Functions
| ask_to_log_crash | Displays the text to ask if the crash should be reported. |
| capture_anyhow | Captures an anyhow error with sentry and sends all previously captured logs. |
| capture_error | Captures an std::error::Error with sentry and sends all previously captured logs. |
| capture_panic | Captures a panic with sentry and sends all previously captured logs. |
| clear_progress_bar | Disables the currently displayed progress bar of the CLI. |
| eprintln | Writes an error to stderr. This function respects the progress bars of the CLI that might be displayed and displays the message above it if any are. |
| init | Initialize the logger. |
| println | Writes a message to stdout with a newline at the end. This function respects the progress bars of the CLI that might be displayed and displays the message above it if any are. |
| set_progress_bar | Sets the currently displayed progress bar of the CLI. |