pub struct RttActiveChannel {
    pub up_channel: Option<UpChannel>,
    pub down_channel: Option<DownChannel>,
    pub channel_name: String,
    pub data_format: DataFormat,
    /* private fields */
}
This is the primary interface through which RTT channel data is read and written. Every actual RTT channel has a configuration and buffer that is used for this purpose.

Fields

up_channel: Option<UpChannel>down_channel: Option<DownChannel>channel_name: Stringdata_format: DataFormat

Implementations

A fully configured RttActiveChannel. The configuration will always try to ‘default’ based on information read from the RTT control block in the binary. Where insufficient information is available, it will use the supplied configuration, with final hardcoded defaults where no other information was available.

Returns the number of the UpChannel.

Polls the RTT target for new data on the channel represented by self. Processes all the new data into the channel internal buffer and returns the number of bytes that was read.

Retrieves available data from the channel and if available, returns Some(channel_number:String, formatted_data:String).