Struct probe_rs_cli_util::rtt::RttActiveTarget
source · [−]pub struct RttActiveTarget {
pub active_channels: Vec<RttActiveChannel>,
pub defmt_state: Option<(Table, Option<Locations>)>,
}Expand description
Once an active connection with the Target RTT control block has been established, we configure each of the active channels, and hold essential state information for successfull communication.
Fields
active_channels: Vec<RttActiveChannel>defmt_state: Option<(Table, Option<Locations>)>Implementations